const express = require("express");
const pool = require("../config/database");
const multer = require("multer");
const path = require("path");
const fs = require("fs");


const router = express.Router();

// ตั้งค่าที่เก็บไฟล์รูป
const uploadDir = "public/uploads";
if (!fs.existsSync(uploadDir)) {
    fs.mkdirSync(uploadDir, { recursive: true });
}

// ตั้งค่า Multer สำหรับอัปโหลดรูป
const storage = multer.diskStorage({
    destination: (req, file, cb) => {
        cb(null, uploadDir);
    },
    filename: (req, file, cb) => {
        cb(null, Date.now() + path.extname(file.originalname)); // ตั้งชื่อไฟล์เป็น timestamp
    }
});
const upload = multer({ storage: storage });

// ดึงสินค้าทั้งหมด
router.get("/", async (req, res) => {
    try {
        const [products] = await pool.execute("SELECT * FROM products");
        res.render("product", { products });
    } catch (error) {
        console.error("Error fetching products:", error);
        res.status(500).send("Error loading products.");
    }
});

// แสดงฟอร์มเพิ่มสินค้า
router.get("/add", (req, res) => {
    res.render("product_add", { message: "" });
});

// เพิ่มสินค้าใหม่พร้อมรูป
router.post('/add', (req, res) => {
    console.log('Request Body:', req.body); // Debug

    // ดึงข้อมูลจาก req.body
    const { name, price, description, stock, image_url } = req.body;

    // ตรวจสอบว่าข้อมูลสำคัญครบหรือไม่
    if (!name || !price || stock === undefined) {
        return res.status(400).json({ message: 'Missing required fields' });
    }

    // SQL Query รองรับ stock และ image_url
    const sql = 'INSERT INTO products (name, price, description, stock, image_url) VALUES (?, ?, ?, ?, ?)';
    const values = [name, price, description || null, stock, image_url || null];

    console.log('SQL Query:', sql, values); // Debug SQL Query

    connection.query(sql, values, (err, result) => {
        if (err) {
            console.error('MySQL Insert Error:', err);
            return res.status(500).json({ message: 'Database error', error: err });
        }
        console.log('Product Added:', result);
        res.status(201).json({ message: 'Product added successfully', result });
    });
});

// ดึงข้อมูลสินค้าตาม ID และแสดงหน้าแก้ไข
router.get("/edit/:id", async (req, res) => {
    try {
        const [rows] = await pool.execute("SELECT * FROM products WHERE id = ?", [req.params.id]);
        if (rows.length === 0) {
            return res.status(404).send("ไม่พบสินค้า");
        }
        res.render("product_edit", { product: rows[0] });
    } catch (error) {
        console.error("Error fetching product:", error);
        res.status(500).send("Error loading product.");
    }
});

// อัปเดตข้อมูลสินค้า
router.post("/edit/:id", upload.single("image"), async (req, res) => {
    try {
        const { name, price, stock, description } = req.body;
        let imagePath = req.body.oldImage; // ใช้รูปเดิมถ้าไม่มีการอัปโหลดใหม่

        // ถ้ามีการอัปโหลดรูปใหม่ ให้ใช้ไฟล์ใหม่
        if (req.file) {
            imagePath = "/uploads/" + req.file.filename;
        }

        console.log("Update values:", { name, price, stock, description, imagePath, id: req.params.id });

        await pool.execute(
            "UPDATE products SET name=?, price=?, stock=?, description=?, image_url=? WHERE id=?",
            [
                name ?? null,
                price ?? null,
                stock ?? null,
                description ?? null,
                imagePath ?? null,
                req.params.id ?? null
            ]
        );

        res.redirect("/products"); // กลับไปยังหน้ารายการสินค้า
    } catch (error) {
        console.error("Error updating product:", error);
        res.status(500).send("Error updating product.");
    }
});


module.exports = router;
